Description Usage Arguments Details Value
BatchGetValuesResponse Object
1 | BatchGetValuesResponse(valueRanges = NULL, spreadsheetId = NULL)
|
valueRanges |
The requested values |
spreadsheetId |
The ID of the spreadsheet the data was retrieved from |
Autogenerated via gar_create_api_objects
The response when retrieving more than one range of values in a spreadsheet.
BatchGetValuesResponse object
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.