PasteDataRequest: PasteDataRequest Object

Description Usage Arguments Details Value

Description

PasteDataRequest Object

Usage

1
2
PasteDataRequest(data = NULL, delimiter = NULL, type = NULL,
  html = NULL, coordinate = NULL)

Arguments

data

The data to insert

delimiter

The delimiter in the data

type

How the data should be pasted

html

True if the data is HTML

coordinate

The coordinate at which the data should start being inserted

Details

Autogenerated via gar_create_api_objects Inserts data into the spreadsheet starting at the specified coordinate.

Value

PasteDataRequest object


bradgwest/googleSheetsR documentation built on May 16, 2019, 3:07 p.m.